@@ -183,7 +183,7 @@ void Control::init () {
         if (str && *str) {
             Playlist *expl = new Playlist (m_app, 0L);
             extra_playlists.append (expl);
-            expl->pretty_name = entry->key + strlen (GCONF_KEY_LISTS) + 1;
+            expl->caption = entry->key + strlen (GCONF_KEY_LISTS) + 1;
             expl->path = str;
             addTree (m_app, expl,
                     gtk_icon_theme_load_icon(icon_theme,
@@ -318,7 +318,7 @@ void Control::openDocument (NodePtr doc, NodePtr cur) {
         playlist_data->document->document()->dispose ();
     doc->document()->notify_listener = this;
     playlist_data->document = doc;
-    cur_url = doc->mrl()->pretty_name;
+    cur_url = doc->caption;
     app_set_title ((const char *) cur_url, m_app);
     back_request = cur;
     g_timeout_add (0, playSchedule, static_cast <void *> (this));
@@ -1135,7 +1135,7 @@ void KMPlayer::jump (Node *n, Control *ctr) {
                 ctr->playlist_data->document->defer ();   // pause
         } else {
             //debugLog() << "jump " << mrl->src << endl;
-            ctr->back_request = n;
+            ctr->back_request = mrl;
             if (ctr->process ()->playing ())
                 ctr->process ()->stop ();
             else
