@@ -1222,7 +1222,7 @@ GenericURL::GenericURL (NodePtr & d, const String & s, const String & name)
     src = s;
     if (!src.isEmpty ())
         setAttribute (StringPool::attr_src, src);
-    pretty_name = name;
+    caption = name;
     if (!name.isEmpty ())
         setAttribute (StringPool::attr_title, name);
 }
@@ -1239,7 +1239,7 @@ GenericMrl::GenericMrl (NodePtr & d, const String & s, const String & name, cons
     src = s;
     if (!src.isEmpty ())
         setAttribute (StringPool::attr_src, src);
-    pretty_name = name;
+    caption = name;
     if (!name.isEmpty ())
         setAttribute (StringPool::attr_name, name);
 }
@@ -1250,12 +1250,12 @@ void GenericMrl::closed () {
         if (src.isEmpty ())
             src = getAttribute (StringPool::attr_url);
     }
-    if (pretty_name.isEmpty ())
-        pretty_name = getAttribute (StringPool::attr_name);
+    if (caption.isEmpty ())
+        caption = getAttribute (StringPool::attr_name);
 }
 
 bool GenericMrl::expose () const {
-    return !pretty_name.isEmpty () || //return false if no title and only one
+    return !caption.isEmpty () || //return false if no caption and only one
         previousSibling () || nextSibling ();
 }
 
